@@ -9,7 +9,6 @@ class Model(object):
     :param str id:
     :param str name:
     :param str project_id:
-    :param str experiment_id:
     :param str cluster_id:
     :param list tags:
     :param str model_type:
@@ -23,7 +22,6 @@ class Model(object):
     id = attr.ib(type=str, default=None)
     name = attr.ib(type=str, default=None)
     project_id = attr.ib(type=str, default=None)
-    experiment_id = attr.ib(type=str, default=None)
     cluster_id = attr.ib(type=str, default=None)
     tags = attr.ib(type=list, factory=list)
     model_type = attr.ib(type=str, default=None)
