@@ -97,7 +97,6 @@ class TestNotebooksCreate(object):
         "--registryUsername", "some_username",
         "--registryPassword", "some_password",
         "--command", "some_entrypoint",
-        "--containerUser", "some_container_user",
         "--shutdownTimeout", "8",
         "--environment", '{"key":"val"}',
         "--isPreemptible",
@@ -112,7 +111,6 @@ class TestNotebooksCreate(object):
         "registryUsername": "some_username",
         "registryPassword": "some_password",
         "command": "c29tZV9lbnRyeXBvaW50",
-        "containerUser": "some_container_user",
         "environment": {"key": "val"},
         "shutdownTimeout": 8,
         "isPreemptible": True,
